@@ -99,6 +99,9 @@ const (
 	FG_PRIORITY_HIGH     = 166
 	FG_PRIORITY_NORMAL   = FG_DEFAULT
 	FG_PRIORITY_LOW      = 245
+	FG_ACTIVE_PRIORITY_CRITICAL = 124
+	FG_ACTIVE_PRIORITY_HIGH     = 130
+	FG_ACTIVE_PRIORITY_LOW      = 238
 	FG_NOTE              = 240
 )
 
