@@ -3,6 +3,7 @@ package dstask
 // main task data structures
 
 import (
+	"errors"
 	"fmt"
 	"log"
 	"os"
@@ -41,7 +42,6 @@ type Project struct {
 
 // LoadTaskSet constructs a TaskSet from a repo path..
 func LoadTaskSet(repoPath, idsFilePath string, includeResolved bool) (*TaskSet, error) {
-
 	// Initialise an empty TaskSet
 	var ts TaskSet
 	ts.tasksByUUID = make(map[string]*Task)
@@ -68,6 +68,7 @@ func LoadTaskSet(repoPath, idsFilePath string, includeResolved bool) (*TaskSet,
 
 	for _, status := range statuses {
 		dir := filepath.Join(repoPath, status)
+
 		files, err := os.ReadDir(dir)
 		if err != nil {
 			if os.IsNotExist(err) {
@@ -75,20 +76,30 @@ func LoadTaskSet(repoPath, idsFilePath string, includeResolved bool) (*TaskSet,
 				// that all status directories exist on program startup.
 				continue
 			}
+
 			return nil, err
 		}
+
 		for _, finfo := range files {
 			// Discard hidden files like .gitkeep
 			if strings.HasPrefix(finfo.Name(), ".") {
 				continue
 			}
+
 			path := filepath.Join(dir, finfo.Name())
+
 			t, err := unmarshalTask(path, finfo, ids, status)
 			if err != nil {
 				log.Printf("error loading task: %v\n", err)
+
+				continue
+			}
+
+			if _, err := ts.LoadTask(t); err != nil {
+				log.Printf("error loading task: %v\n", err)
+
 				continue
 			}
-			ts.LoadTask(t)
 		}
 	}
 
@@ -115,10 +126,16 @@ func (ts *TaskSet) SortByCreated(dir SortByDirection) {
 	switch dir {
 	case Ascending:
 		// Oldest first
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Created.Before(ts.tasks[j].Created) })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Created.Before(ts.tasks[j].Created) },
+		)
 	case Descending:
 		// Newest first
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Created.After(ts.tasks[j].Created) })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Created.After(ts.tasks[j].Created) },
+		)
 	}
 }
 
@@ -126,10 +143,16 @@ func (ts *TaskSet) SortByPriority(dir SortByDirection) {
 	switch dir {
 	case Ascending:
 		// P1 first
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Priority < ts.tasks[j].Priority })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Priority < ts.tasks[j].Priority },
+		)
 	case Descending:
 		// P1 last
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Priority > ts.tasks[j].Priority })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Priority > ts.tasks[j].Priority },
+		)
 	}
 }
 
@@ -137,10 +160,16 @@ func (ts *TaskSet) SortByResolved(dir SortByDirection) {
 	switch dir {
 	case Ascending:
 		// Oldest resolved first
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Resolved.Before(ts.tasks[j].Resolved) })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Resolved.Before(ts.tasks[j].Resolved) },
+		)
 	case Descending:
 		// Newest resolved first
-		sort.SliceStable(ts.tasks, func(i, j int) bool { return ts.tasks[i].Resolved.After(ts.tasks[j].Resolved) })
+		sort.SliceStable(
+			ts.tasks,
+			func(i, j int) bool { return ts.tasks[i].Resolved.After(ts.tasks[j].Resolved) },
+		)
 	}
 }
 
@@ -150,6 +179,7 @@ func (ts *TaskSet) MustLoadTask(task Task) Task {
 	if err != nil {
 		ExitFail("%s, task %s", err, task.UUID)
 	}
+
 	return newTask
 }
 
@@ -182,6 +212,7 @@ func (ts *TaskSet) LoadTask(task Task) (Task, error) {
 		for id := 1; id <= MAX_TASKS_OPEN; id++ {
 			if ts.tasksByID[id] == nil {
 				task.ID = id
+
 				break
 			}
 		}
@@ -212,25 +243,26 @@ func (ts *TaskSet) UpdateTask(task Task) error {
 	task.Normalise()
 
 	if err := task.Validate(); err != nil {
-		return fmt.Errorf("%s, task %s", err, task.UUID)
+		return fmt.Errorf("%w, task %s", err, task.UUID)
 	}
 
 	if ts.tasksByUUID[task.UUID] == nil {
-		return fmt.Errorf("Could not find given task to update by UUID")
+		return errors.New("could not find given task to update by UUID")
 	}
 
 	if !IsValidPriority(task.Priority) {
-		return fmt.Errorf("Invalid priority specified")
+		return errors.New("invalid priority specified")
 	}
 
 	old := ts.tasksByUUID[task.UUID]
 
 	if old.Status != task.Status && !IsValidStateTransition(old.Status, task.Status) {
-		return fmt.Errorf("Invalid state transition: %s -> %s", old.Status, task.Status)
+		return fmt.Errorf("invalid state transition: %s -> %s", old.Status, task.Status)
 	}
 
-	if old.Status != task.Status && task.Status == STATUS_RESOLVED && strings.Contains(task.Notes, "- [ ] ") {
-		return fmt.Errorf("Refusing to resolve task with incomplete tasklist")
+	if old.Status != task.Status && task.Status == STATUS_RESOLVED &&
+		strings.Contains(task.Notes, "- [ ] ") {
+		return errors.New("refusing to resolve task with incomplete tasklist")
 	}
 
 	if task.Status == STATUS_RESOLVED {
@@ -244,6 +276,7 @@ func (ts *TaskSet) UpdateTask(task Task) error {
 	task.WritePending = true
 	// existing pointer must point to address of new task copied
 	*ts.tasksByUUID[task.UUID] = task
+
 	return nil
 }
 
@@ -276,6 +309,7 @@ func (ts *TaskSet) MustGetByID(id int) Task {
 	if err != nil {
 		ExitFail(err.Error())
 	}
+
 	return task
 }
 
@@ -294,6 +328,7 @@ func (ts *TaskSet) Tasks() []Task {
 			tasks = append(tasks, *task)
 		}
 	}
+
 	return tasks
 }
 
@@ -302,6 +337,7 @@ func (ts *TaskSet) AllTasks() []Task {
 	for _, task := range ts.tasks {
 		tasks = append(tasks, *task)
 	}
+
 	return tasks
 }
 
